(self.webpackChunklab2hub=self.webpackChunklab2hub||[]).push([[568],{568:(t,a,e)=>{"use strict";e.r(a),e.d(a,{default:()=>u});var o=e(82),n=e(510);const u={id:"lab2hub-menu",autoStart:!0,requires:[e(635).ICommandPalette,o.IMainMenu],activate:(t,a,e)=>{const{commands:o}=t,u="lab2hub:home";o.addCommand(u,{label:"Return to Home",caption:"Navigate to the Control Panel on JupyterHub",execute:t=>{location.assign(location.origin+"/home")}});const i="lab2hub:logout";o.addCommand(i,{label:"Log Out",caption:"Logout doesn't shutdown the running instance",execute:t=>{location.assign(location.origin+"/logout")}});const m="Extension by Motionlife";a.addItem({command:u,category:m,args:{origin:"from the jupyterlab's palette"}}),a.addItem({command:i,category:m,args:{origin:"from the jupyterlab's palette"}});const l=new n.Menu({commands:o});l.title.label="Hub",e.addMenu(l,{rank:100}),l.addItem({command:u,args:{origin:"from the jupyterlab's menu"}}),l.addItem({command:i,args:{origin:"from the jupyterlab's menu"}})}}}}]);